@@ -2,14 +2,14 @@
 #' @export CFA
 #' @exportClass CFA
 #' @description Calculates various coefficients for the Configural Frequencies Analysis (CFA) defining main- and (optionaly) interaction effects. The core principle is to use \code{\link{glm}} in package \code{stats} to calculate the expected counts considering a designmatrix, which is constructed based on an formular definition given in argument \code{form}. 
-#' @details This is the main function of the package. It internaly calls several functions of the package \code{\link{confreq}} which are also available as single functions. For clasification of the observed patterns into 'Types' and 'Antitypes' according to Linert  (1971), a S3 summary method for the resulting object of class \code{"CFA"} can be applied - see \code{\link{summary.CFA}}.
+#' @details This is the main function of the package. It internaly calls several functions of the package \code{\link{confreq}} which are also available as single functions. For clasification of the observed patterns into 'Types' and 'Antitypes' according to Lienert  (1971), a S3 summary method for the resulting object of class \code{"CFA"} can be applied - see \code{\link{summary.CFA}}.
 #' 
 #' @param patternfreq an object of class \code{"Pfreq"}, which is data in pattern frequencies representation - see function \code{\link{dat2fre}}.
 #' 
 #' @param alpha a numeric giving the alpha level for testing (default set to \code{alpha=.05})
 #'    
 #' @param form either a character expression which can be coerced into a model formula with the function \code{as.formula} in the package \code{stats}. If this argument is left empty (at default \code{form=NULL}) the (internal) function \code{design_cfg_cfa()} will return a designmatrix coding only main effects and no interactions -- for a designmatrix refering to  three variables (V1, V2, V3) for example, leaving the argument \code{form} empty will be equivalent to assigning the character \code{"~ V1 + V2 + V3"} to the argument (\code{form="~ V1 + V2 + V3"}).
-#'  A special Case is to define a null-model or rather a cfa model of order zero. In such a model no (main) effects are considered. This can be achieved bei passing the character expression \code{"null"} to the argument \code{form} -- so: \code{form = "null"} -- not to be confound with the default setting of this argument \code{form=NULL}. Another option is to define your own designmatrix and assign it to this argument (\code{form}) in this case the object assigned to \code{form} musst be of class \code{"matrix"} and must logicaly match to the argument \code{patternfreq}, which is currently not checked! - but simply assumed.   
+#'  A special case is to define a null-model or rather a cfa model of order zero. In such a model no (main) effects are considered. This can be achieved bei passing the character expression \code{"null"} to the argument \code{form} -- so: \code{form = "null"} -- not to be confound with the default setting of this argument \code{form=NULL}. Another option is to define your own designmatrix and assign it to this argument (\code{form}) in this case the object assigned to \code{form} musst be of class \code{"matrix"} and must logicaly match to the argument \code{patternfreq}, which is currently not checked! - but simply assumed.   
 #' 
 #' @param ccor either a logical (TRUE / FALSE) determining wether to apply a continuity correction or not. When set to \code{ccor=TRUE} continuity correction is applied for expected values 5 =< expected =< 10. For \code{ccor=FALSE} no continuity correction is applied. Another option is to set \code{ccor=c(x,y)} where x is the lower and y the upper bound for expected values where continuity correction is applied. So \code{ccor=c(5,10)} is equivalent to \code{ccor=TRUE}.
 #' 
@@ -17,14 +17,17 @@
 #' 
 #' @param intercept argument passed to \code{\link{glm.fit}} with default set to \code{FALSE} 
 #' 
-#' @param method charcter defining the estimation method for expected frequencies with default set to \code{method="log"} to estimate the expected frequencies using \code{\link{glm}}. An other option is to set this argument to \code{method="margins"} which will result in expected frequencies calculated based on the margins of the multidimensional contigency table. Only main effects models are posible in this case and thus the arguments \code{form}, \code{family} and \code{intercept} are ignored.
+#' @param method charcter defining the estimation method for expected frequencies with default set to \code{method="log"} to estimate the expected frequencies using \code{\link{glm}}. An other option is to set this argument to \code{method="margins"} which will result in expected frequencies calculated based on the margins of the multidimensional contigency table. Only main effects models are posible in this case and thus the arguments \code{form}, \code{family} \code{cova} and \code{intercept} are ignored.
 #' 
-#' @param blank unsed only if argument \code{method} is set to \code{method="margins"} otherwise ignored. Should be either (1) character vector defining the pattern (with spaces between variable categories), which will be ignored for calculation of expected frequencies; or (2) a numeric vector defining the position(s) of the pattern in object of class \code{"Pfreq"} (see. argument \code{patternfreq}), which will be ignored for calculation of expected frequencies. At default (\code{blank=NULL}) all possible pattern, as listed in object of class \code{"Pfreq"}, are included for calculation of expected frequencies.  
-#'  
+#' @param blank can be used to indicate which pattern (configurations) are declared as structural cells (confgurations) for functional CFA. Should be either (1) a character vector defining the pattern (with spaces between variable categories), which will be ignored for calculation of expected frequencies; or (2) a numeric vector defining the (row) positions of the pattern in an object of class \code{"Pfreq"} (see. argument \code{patternfreq}), which will be ignored for calculation of expected frequencies. At default (\code{blank=NULL}) all possible pattern, as listed in object of class \code{"Pfreq"}, are included for calculation of expected frequencies.  
+#' 
+#' @param cova a matrix (possibly with one or more columns) holding the covariate (mean) values for each pattern (configurations) see function \code{\link{dat2cov}} . 
 #' @param ... additional parameters passed through to other functions.
 #' @return an object of class \code{CFA} with results.
 #' @references Lienert, G. A. (1971). Die Konfigurationsfrequenzanalyse: I. Ein neuer Weg zu Typen und Syndromen. \emph{Zeitschrift für Klinische Psychologie und Psychotherapie, 19}(2), 99-115. 
-#' 
+#' @references Glück, J., & Von Eye, A. (2000). Including covariates in configural frequency analysis. \emph{Psychologische Beitrage, 42}, 405–417.
+#' @references Victor, N. (1989). An Alternativ Approach to Configural Frequency Analysis. \emph{Methodika, 3}, 61–73.
+#' @references Stemmler, M. (2014). \emph{Person-Centered Methods}. Cham: Springer International Publishing.
 #' @examples #######################################
 #' ######### some examples ########
 #' data(LienertLSD)
@@ -45,7 +48,7 @@
 #' summary(res4)
 
 ############### start of function definition ##################
-CFA<-function(patternfreq, alpha=.05, form=NULL, ccor=FALSE, family=poisson(), intercept=FALSE, method="log", blank=NULL,...){
+CFA<-function(patternfreq, alpha=.05, form=NULL, ccor=FALSE, family=poisson(), intercept=FALSE, method="log", blank=NULL, cova=NULL, ...){
   
 if(any(class(patternfreq)=="Pfreq") != TRUE){stop("patternfreq must be an object of class 'Pfreq'","\n","see func. dat2fre()", call. = TRUE) }
 
@@ -63,6 +66,29 @@ if(method=="log"){
     designmatrix <- design_cfg_cfa(kat=kategorie , form = form, ...) 
     
     usedform <- form
+    
+    #option added 18-11-2016 
+    if(!is.null(blank)){
+      if(class(blank)!="character"){
+        blank_which <- blank
+        Mi <- sapply(blank_which,function(x){b <- (rep(0,length.out=nrow(designmatrix))); b[x] <- 1; b})
+        designmatrix <- cbind(designmatrix, Mi)
+        usedform <- paste(paste(form),"; and functional pattern:", paste(pattern[blank],collapse = ", "))
+      }
+      if(class(blank)=="character"){
+        blank_which <- sapply(blank, function(x){which(x==pattern)})
+        Mi <- sapply(blank_which,function(x){b <- (rep(0,length.out=nrow(designmatrix))); b[x] <- 1; b})
+        designmatrix <- cbind(designmatrix, Mi)
+        usedform <- paste(paste(form),"; and functional pattern:", paste(blank,collapse = ", "))
+      }  
+    }else{blank_which <- blank}
+    #option added 18-11-2016
+    if(!is.null(cova)){
+      designmatrix <- cbind(designmatrix, cova)
+      usedform <- paste(usedform, "; and",ncol(cova) , "covariates") 
+      }
+    
+    
   }
   
   if(class(form)=="matrix"){designmatrix <- form ; usedform <- "designmatrix" } # !!! no further checks !!!
@@ -111,7 +137,7 @@ lr.p <- (1-pchisq(lr.chi,df)) ## added 20. October 2014 JHH
   
 bonferroni <- alpha/length(expected)
   
-result <- list( local.test = erg, bonferroni.alpha=bonferroni, global.test = list(pearson = list(Chi=chi.square,df=df,pChi=chi.square.p,alpha=alpha), likelihood.ratio = list(Chi=lr.chi,df=df,pChi=lr.p,alpha=alpha), infocrit=list(loglik=loglik, AIC=aic, BIC=bic)),designmatrix=designmatrix, variables=kategorie, used.formula=usedform) 
+result <- list( local.test = erg, bonferroni.alpha=bonferroni, global.test = list(pearson = list(Chi=chi.square,df=df,pChi=chi.square.p,alpha=alpha), likelihood.ratio = list(Chi=lr.chi,df=df,pChi=lr.p,alpha=alpha), infocrit=list(loglik=loglik, AIC=aic, BIC=bic)),designmatrix=designmatrix, variables=kategorie, used.formula=usedform, functional=blank_which) 
   
 class(result)<-c("CFA","list")
  
